How to generate a PIP package?
https://packaging.python.org/en/latest/tutorials/packaging-projects/

change setup.cfg version
py -m build
py -m twine upload --skip-existing dist/*

api-key=pypi-AgEIcHlwaS5vcmcCJDQ0MDU1MDYwLTQzNmEtNGQxNy1iNGRmLWEzYjcxM2Y3OTEzNwACFlsxLFsic2NyYXBlYW55dGhpbmciXV0AAixbMixbIjU3MTA5MDEwLTdmYTEtNGMzNi1hZGVhLTg1NGZiYmI0OWYwMyJdXQAABiDrhPZ-dGDC9wJZz4L43Vau25qS3ivVzbQ84tK8fOiOZA